==> mfc-es-api-1.1.2-sources.jar: com/mfc/es/api/model/service/media/MediaDetail.java <==
package com.mfc.es.api.model.service.media;

import com.mfc.es.api.model.service.base.AbstractDoc;

import java.util.*;

/**
 * Created by Frank.Huang on 2017/3/3.
 */
public class MediaDetail extends AbstractDoc {
    private String displayId = "";
    /**
     * meta来源: 0 自建 1 imdb 2 tmdb
     */
    private Integer metaSourceType = 1;
    private String originalTitle = "";
    /**
     * 是否成人节目: 0 否, 1 是
     */
    private Integer adult = 0;
    /**
     * 时长(秒)
     */
    private Long runtime = 0L;
    /**
     * 流行指数
     */
    private Double popularity = 0.0;
    /**
     * 评分
     */
    private Double rating = 0.0;
    /**
     * 权重评分
     */
    private Double weightRating = 0.0;
    private Integer voteCount = 0;
    private Integer mediaType = 0;
    private Integer status = 0;
    private Integer mediaFormat = 0;
    private Integer hasEnglish = 0;
    private Integer hasArtwork = 0;
    private Integer limitLevel = 0;
    private Set<String> languages = new LinkedHashSet();
    private Set<Long> countries = new LinkedHashSet();
    private Set<Long> genres = new LinkedHashSet();
    private String releaseDate;
    private Integer releaseDateInt = 0;
    private String releaseCountryCode = "";
    private Integer year = 0;
    private Long seriesId = 0L;
    private Long seasonId = 0L;
    private Integer season = 0;
    private Integer episode = 0;
    private Integer seasonNo = 0;
    private Integer episodeNo = 0;
    private Set<Long> clouds = new LinkedHashSet();
    private Set<String> cloudsAudioLanguage = new LinkedHashSet();
    private Integer audioLanguageNo = 0;
    private Set<Long> similars = new LinkedHashSet();
    private Date createTime;

    private Long connectedTime = 0L;
    private String firstAirDate;
    private Integer firstAirDateInt = 0;
    private String lastAirDate;
    private Integer lastAirDateInt = 0;
    private String linkedLastAirDate;
    private Integer linkedLastAirDateInt = 0;


    private List<MediaCertification> certifications = new ArrayList<>();
    private List<MediaCast> casts = new ArrayList<>();
    private List<Summary> summaries = new ArrayList<>();
    private List<MediaTrailer> trailers = new ArrayList<>();
    private List<MediaRelease> release = new ArrayList<>();
    private List<MediaAKA> akas = new ArrayList<>();

    private List<MediaPlaylist> playlists = new ArrayList<>();//列表
    private int latestSeason;//tv最后更新season
    private int latestEpisode;//tv最后更新episode

    public String getDisplayId() {
        return displayId;
    }

    public void setDisplayId(String displayId) {
        this.displayId = displayId;
    }

    public Integer getMetaSourceType() {
        return metaSourceType;
    }

    public void setMetaSourceType(Integer metaSourceType) {
        this.metaSourceType = metaSourceType;
    }

    public Integer getAdult() {
        return adult;
    }

    public void setAdult(Integer adult) {
        this.adult = adult;
    }

    public Long getRuntime() {
        return runtime;
    }

    public void setRuntime(Long runtime) {
        this.runtime = runtime;
    }

    public Double getPopularity() {
        return popularity;
    }

    public void setPopularity(Double popularity) {
        this.popularity = popularity;
    }

    public Double getRating() {
        return rating;
    }

    public void setRating(Double rating) {
        this.rating = rating;
    }

    public Double getWeightRating() {
        return weightRating;
    }

    public void setWeightRating(Double weightRating) {
        this.weightRating = weightRating;
    }

    public Integer getVoteCount() {
        return voteCount;
    }

    public void setVoteCount(Integer voteCount) {
        this.voteCount = voteCount;
    }

    public Integer getMediaType() {
        return mediaType;
    }

    public void setMediaType(Integer mediaType) {
        this.mediaType = mediaType;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getMediaFormat() {
        return mediaFormat;
    }

    public void setMediaFormat(Integer mediaFormat) {
        this.mediaFormat = mediaFormat;
    }

    public Integer getHasEnglish() {
        return hasEnglish;
    }

    public void setHasEnglish(Integer hasEnglish) {
        this.hasEnglish = hasEnglish;
    }

    public Integer getHasArtwork() {
        return hasArtwork;
    }

    public void setHasArtwork(Integer hasArtwork) {
        this.hasArtwork = hasArtwork;
    }

    public Integer getLimitLevel() {
        return limitLevel;
    }

    public void setLimitLevel(Integer limitLevel) {
        this.limitLevel = limitLevel;
    }

    public Set<String> getLanguages() {
        return languages;
    }

    public void setLanguages(Set<String> languages) {
        this.languages = languages;
    }

    public Set<Long> getCountries() {
        return countries;
    }

    public void setCountries(Set<Long> countries) {
        this.countries = countries;
    }

    public Set<Long> getGenres() {
        return genres;
    }

    public void setGenres(Set<Long> genres) {
        this.genres = genres;
    }

    public String getReleaseDate() {
        return releaseDate;
    }

    public void setReleaseDate(String releaseDate) {
        this.releaseDate = releaseDate;
    }

    public Integer getReleaseDateInt() {
        return releaseDateInt;
    }

    public void setReleaseDateInt(Integer releaseDateInt) {
        this.releaseDateInt = releaseDateInt;
    }

    public String getReleaseCountryCode() {
        return releaseCountryCode;
    }

    public void setReleaseCountryCode(String releaseCountryCode) {
        this.releaseCountryCode = releaseCountryCode;
    }

    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }

    public Long getSeriesId() {
        return seriesId;
    }

    public void setSeriesId(Long seriesId) {
        this.seriesId = seriesId;
    }

    public Long getSeasonId() {
        return seasonId;
    }

    public void setSeasonId(Long seasonId) {
        this.seasonId = seasonId;
    }

    public Integer getSeason() {
        return season;
    }

    public void setSeason(Integer season) {
        this.season = season;
    }

    public Integer getEpisode() {
        return episode;
    }

    public void setEpisode(Integer episode) {
        this.episode = episode;
    }

    public Set<Long> getClouds() {
        return clouds;
    }

    public void setClouds(Set<Long> clouds) {
        this.clouds = clouds;
    }

    public Integer getAudioLanguageNo() {
        return audioLanguageNo;
    }

    public void setAudioLanguageNo(Integer audioLanguageNo) {
        this.audioLanguageNo = audioLanguageNo;
    }

    public Set<Long> getSimilars() {
        return similars;
    }

    public void setSimilars(Set<Long> similars) {
        this.similars = similars;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Long getConnectedTime() {
        return connectedTime;
    }

    public void setConnectedTime(Long connectedTime) {
        this.connectedTime = connectedTime;
    }

    public String getLastAirDate() {
        return lastAirDate;
    }

    public void setLastAirDate(String lastAirDate) {
        this.lastAirDate = lastAirDate;
    }

    public Integer getLastAirDateInt() {
        return lastAirDateInt;
    }

    public void setLastAirDateInt(Integer lastAirDateInt) {
        this.lastAirDateInt = lastAirDateInt;
    }

    public List<MediaCertification> getCertifications() {
        return certifications;
    }

    public void setCertifications(List<MediaCertification> certifications) {
        this.certifications = certifications;
    }

    public List<MediaCast> getCasts() {
        return casts;
    }

    public void setCasts(List<MediaCast> casts) {
        this.casts = casts;
    }

    public List<Summary> getSummaries() {
        return summaries;
    }

    public void setSummaries(List<Summary> summaries) {
        this.summaries = summaries;
    }

    public List<MediaTrailer> getTrailers() {
        return trailers;
    }

    public void setTrailers(List<MediaTrailer> trailers) {
        this.trailers = trailers;
    }

    public String getOriginalTitle() {
        return originalTitle;
    }

    public void setOriginalTitle(String originalTitle) {
        this.originalTitle = originalTitle;
    }

    public Integer getSeasonNo() {
        return seasonNo;
    }

    public void setSeasonNo(Integer seasonNo) {
        this.seasonNo = seasonNo;
    }

    public Integer getEpisodeNo() {
        return episodeNo;
    }

    public void setEpisodeNo(Integer episodeNo) {
        this.episodeNo = episodeNo;
    }

    public List<MediaRelease> getRelease() {
        return release;
    }

    public void setRelease(List<MediaRelease> release) {
        this.release = release;
    }

    public List<MediaAKA> getAkas() {
        return akas;
    }

    public void setAkas(List<MediaAKA> akas) {
        this.akas = akas;
    }

    public String getFirstAirDate() {
        return firstAirDate;
    }

    public void setFirstAirDate(String firstAirDate) {
        this.firstAirDate = firstAirDate;
    }

    public Integer getFirstAirDateInt() {
        return firstAirDateInt;
    }

    public void setFirstAirDateInt(Integer firstAirDateInt) {
        this.firstAirDateInt = firstAirDateInt;
    }

    public Set<String> getCloudsAudioLanguage() {
        return cloudsAudioLanguage;
    }

    public void setCloudsAudioLanguage(Set<String> cloudsAudioLanguage) {
        this.cloudsAudioLanguage = cloudsAudioLanguage;
    }

    public String getLinkedLastAirDate() {
        return linkedLastAirDate;
    }

    public void setLinkedLastAirDate(String linkedLastAirDate) {
        this.linkedLastAirDate = linkedLastAirDate;
    }

    public Integer getLinkedLastAirDateInt() {
        return linkedLastAirDateInt;
    }

    public void setLinkedLastAirDateInt(Integer linkedLastAirDateInt) {
        this.linkedLastAirDateInt = linkedLastAirDateInt;
    }

    public List<MediaPlaylist> getPlaylists() {
        return playlists;
    }

    public void setPlaylists(List<MediaPlaylist> playlists) {
        this.playlists = playlists;
    }

    public int getLatestSeason() {
        return latestSeason;
    }

    public void setLatestSeason(int latestSeason) {
        this.latestSeason = latestSeason;
    }

    public int getLatestEpisode() {
        return latestEpisode;
    }

    public void setLatestEpisode(int latestEpisode) {
        this.latestEpisode = latestEpisode;
    }
}

==> mfc-es-api-1.3.2-sources.jar: com/mfc/es/api/model/service/media/MediaDetail.java <==
package com.mfc.es.api.model.service.media;

import com.mfc.es.api.model.service.base.AbstractDoc;

import java.util.*;

/**
 * Created by Frank.Huang on 2017/3/3.
 */
public class MediaDetail extends AbstractDoc {
    private String displayId = "";
    /**
     * meta来源: 0 自建 1 imdb 2 tmdb
     */
    private Integer metaSourceType = 1;
    private String originalTitle = "";
    /**
     * 是否成人节目: 0 否, 1 是
     */
    private Integer adult = 0;
    /**
     * 时长(秒)
     */
    private Long runtime = 0L;
    /**
     * 流行指数
     */
    private Double popularity = 0.0;
    /**
     * 评分
     */
    private Double rating = 0.0;
    /**
     * 权重评分
     */
    private Double weightRating = 0.0;
    private Integer voteCount = 0;
    private Integer mediaType = 0;
    private Integer status = 0;
    private Integer mediaFormat = 0;
    private Integer hasEnglish = 0;
    private Integer hasArtwork = 0;
    private Integer limitLevel = 0;
    private LinkedHashSet<String> languages = new LinkedHashSet();
    private LinkedHashSet<Long> countries = new LinkedHashSet();
    private Set<Long> genres = new LinkedHashSet();
    private Set<String> companies = new LinkedHashSet();
    private Set<String> disCompanies = new LinkedHashSet();

    private String releaseDate;
    private Integer releaseDateInt = 0;
    private String releaseCountryCode = "";
    private Integer year = 0;
    private Long seriesId = 0L;
    private Long seasonId = 0L;
    private Integer season = 0;
    private Integer episode = 0;
    private Integer seasonNo = 0;
    private Integer episodeNo = 0;
    private Set<Long> clouds = new LinkedHashSet();
    private Set<String> cloudsAudioLanguage = new LinkedHashSet();
    private Integer audioLanguageNo = 0;
    private LinkedHashSet<Long> similars = new LinkedHashSet();
    private Date createTime;
    private String ppId;
    private String firstLanguage;


    private Long connectedTime = 0L;
    private String firstAirDate;
    private Integer firstAirDateInt = 0;
    private String lastAirDate;
    private Integer lastAirDateInt = 0;
    private String linkedLastAirDate;
    private Integer linkedLastAirDateInt = 0;
    private String onTheAirAllLastAirDate;
    private Integer onTheAirAllLastAirDateInt = 0;

    private List<MediaCertification> certifications = new ArrayList<>();
    private List<MediaCast> casts = new ArrayList<>();
    private List<Summary> summaries = new ArrayList<>();
    private List<MediaTrailer> trailers = new ArrayList<>();
    private List<MediaRelease> release = new ArrayList<>();
    private List<MediaAKA> akas = new ArrayList<>();

    private List<MediaPlaylist> playlists = new ArrayList<>();//列表
    private List<MediaTag> tags = new ArrayList<>();//标签

    private int latestSeason;//tv有资源最后更新season
    private int latestEpisode;//tv有资源最后更新episode
    private int onTheAirAllLatestSeason;//tv ontheair最后更新season
    private int onTheAirAllLatestEpisode;//tv ontheair有资源最后更新episode

    public String getDisplayId() {
        return displayId;
    }

    public void setDisplayId(String displayId) {
        this.displayId = displayId;
    }

    public Integer getMetaSourceType() {
        return metaSourceType;
    }

    public void setMetaSourceType(Integer metaSourceType) {
        this.metaSourceType = metaSourceType;
    }

    public Integer getAdult() {
        return adult;
    }

    public void setAdult(Integer adult) {
        this.adult = adult;
    }

    public Long getRuntime() {
        return runtime;
    }

    public void setRuntime(Long runtime) {
        this.runtime = runtime;
    }

    public Double getPopularity() {
        return popularity;
    }

    public void setPopularity(Double popularity) {
        this.popularity = popularity;
    }

    public Double getRating() {
        return rating;
    }

    public void setRating(Double rating) {
        this.rating = rating;
    }

    public Double getWeightRating() {
        return weightRating;
    }

    public void setWeightRating(Double weightRating) {
        this.weightRating = weightRating;
    }

    public Integer getVoteCount() {
        return voteCount;
    }

    public void setVoteCount(Integer voteCount) {
        this.voteCount = voteCount;
    }

    public Integer getMediaType() {
        return mediaType;
    }

    public void setMediaType(Integer mediaType) {
        this.mediaType = mediaType;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getMediaFormat() {
        return mediaFormat;
    }

    public void setMediaFormat(Integer mediaFormat) {
        this.mediaFormat = mediaFormat;
    }

    public Integer getHasEnglish() {
        return hasEnglish;
    }

    public void setHasEnglish(Integer hasEnglish) {
        this.hasEnglish = hasEnglish;
    }

    public Integer getHasArtwork() {
        return hasArtwork;
    }

    public void setHasArtwork(Integer hasArtwork) {
        this.hasArtwork = hasArtwork;
    }

    public Integer getLimitLevel() {
        return limitLevel;
    }

    public void setLimitLevel(Integer limitLevel) {
        this.limitLevel = limitLevel;
    }

    public LinkedHashSet<String> getLanguages() {
        return languages;
    }

    public void setLanguages(LinkedHashSet<String> languages) {
        this.languages = languages;
    }

    public LinkedHashSet<Long> getCountries() {
        return countries;
    }

    public void setCountries(LinkedHashSet<Long> countries) {
        this.countries = countries;
    }

    public Set<Long> getGenres() {
        return genres;
    }

    public void setGenres(Set<Long> genres) {
        this.genres = genres;
    }

    public Set<String> getCompanies() {
        return companies;
    }

    public void setCompanies(Set<String> companies) {
        this.companies = companies;
    }

    public Set<String> getDisCompanies() {
        return disCompanies;
    }

    public void setDisCompanies(Set<String> disCompanies) {
        this.disCompanies = disCompanies;
    }

    public String getReleaseDate() {
        return releaseDate;
    }

    public void setReleaseDate(String releaseDate) {
        this.releaseDate = releaseDate;
    }

    public Integer getReleaseDateInt() {
        return releaseDateInt;
    }

    public void setReleaseDateInt(Integer releaseDateInt) {
        this.releaseDateInt = releaseDateInt;
    }

    public String getReleaseCountryCode() {
        return releaseCountryCode;
    }

    public void setReleaseCountryCode(String releaseCountryCode) {
        this.releaseCountryCode = releaseCountryCode;
    }

    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }

    public Long getSeriesId() {
        return seriesId;
    }

    public void setSeriesId(Long seriesId) {
        this.seriesId = seriesId;
    }

    public Long getSeasonId() {
        return seasonId;
    }

    public void setSeasonId(Long seasonId) {
        this.seasonId = seasonId;
    }

    public Integer getSeason() {
        return season;
    }

    public void setSeason(Integer season) {
        this.season = season;
    }

    public Integer getEpisode() {
        return episode;
    }

    public void setEpisode(Integer episode) {
        this.episode = episode;
    }

    public Set<Long> getClouds() {
        return clouds;
    }

    public void setClouds(Set<Long> clouds) {
        this.clouds = clouds;
    }

    public Integer getAudioLanguageNo() {
        return audioLanguageNo;
    }

    public void setAudioLanguageNo(Integer audioLanguageNo) {
        this.audioLanguageNo = audioLanguageNo;
    }

    public LinkedHashSet<Long> getSimilars() {
        return similars;
    }

    public void setSimilars(LinkedHashSet<Long> similars) {
        this.similars = similars;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getPpId() {
        return ppId;
    }

    public void setPpId(String ppId) {
        this.ppId = ppId;
    }

    public String getFirstLanguage() {
        return firstLanguage;
    }

    public void setFirstLanguage(String firstLanguage) {
        this.firstLanguage = firstLanguage;
    }

    public Long getConnectedTime() {
        return connectedTime;
    }

    public void setConnectedTime(Long connectedTime) {
        this.connectedTime = connectedTime;
    }

    public String getLastAirDate() {
        return lastAirDate;
    }

    public void setLastAirDate(String lastAirDate) {
        this.lastAirDate = lastAirDate;
    }

    public Integer getLastAirDateInt() {
        return lastAirDateInt;
    }

    public void setLastAirDateInt(Integer lastAirDateInt) {
        this.lastAirDateInt = lastAirDateInt;
    }

    public List<MediaCertification> getCertifications() {
        return certifications;
    }

    public void setCertifications(List<MediaCertification> certifications) {
        this.certifications = certifications;
    }

    public List<MediaCast> getCasts() {
        return casts;
    }

    public void setCasts(List<MediaCast> casts) {
        this.casts = casts;
    }

    public List<Summary> getSummaries() {
        return summaries;
    }

    public void setSummaries(List<Summary> summaries) {
        this.summaries = summaries;
    }

    public List<MediaTrailer> getTrailers() {
        return trailers;
    }

    public void setTrailers(List<MediaTrailer> trailers) {
        this.trailers = trailers;
    }

    public String getOriginalTitle() {
        return originalTitle;
    }

    public void setOriginalTitle(String originalTitle) {
        this.originalTitle = originalTitle;
    }

    public Integer getSeasonNo() {
        return seasonNo;
    }

    public void setSeasonNo(Integer seasonNo) {
        this.seasonNo = seasonNo;
    }

    public Integer getEpisodeNo() {
        return episodeNo;
    }

    public void setEpisodeNo(Integer episodeNo) {
        this.episodeNo = episodeNo;
    }

    public List<MediaRelease> getRelease() {
        return release;
    }

    public void setRelease(List<MediaRelease> release) {
        this.release = release;
    }

    public List<MediaAKA> getAkas() {
        return akas;
    }

    public void setAkas(List<MediaAKA> akas) {
        this.akas = akas;
    }

    public String getFirstAirDate() {
        return firstAirDate;
    }

    public void setFirstAirDate(String firstAirDate) {
        this.firstAirDate = firstAirDate;
    }

    public Integer getFirstAirDateInt() {
        return firstAirDateInt;
    }

    public void setFirstAirDateInt(Integer firstAirDateInt) {
        this.firstAirDateInt = firstAirDateInt;
    }

    public Set<String> getCloudsAudioLanguage() {
        return cloudsAudioLanguage;
    }

    public void setCloudsAudioLanguage(Set<String> cloudsAudioLanguage) {
        this.cloudsAudioLanguage = cloudsAudioLanguage;
    }

    public String getLinkedLastAirDate() {
        return linkedLastAirDate;
    }

    public void setLinkedLastAirDate(String linkedLastAirDate) {
        this.linkedLastAirDate = linkedLastAirDate;
    }

    public Integer getLinkedLastAirDateInt() {
        return linkedLastAirDateInt;
    }

    public void setLinkedLastAirDateInt(Integer linkedLastAirDateInt) {
        this.linkedLastAirDateInt = linkedLastAirDateInt;
    }

    public List<MediaPlaylist> getPlaylists() {
        return playlists;
    }

    public void setPlaylists(List<MediaPlaylist> playlists) {
        this.playlists = playlists;
    }

    public List<MediaTag> getTags() {
        return tags;
    }

    public void setTags(List<MediaTag> tags) {
        this.tags = tags;
    }

    public int getLatestSeason() {
        return latestSeason;
    }

    public void setLatestSeason(int latestSeason) {
        this.latestSeason = latestSeason;
    }

    public int getLatestEpisode() {
        return latestEpisode;
    }

    public void setLatestEpisode(int latestEpisode) {
        this.latestEpisode = latestEpisode;
    }

    public String getOnTheAirAllLastAirDate() {
        return onTheAirAllLastAirDate;
    }

    public void setOnTheAirAllLastAirDate(String onTheAirAllLastAirDate) {
        this.onTheAirAllLastAirDate = onTheAirAllLastAirDate;
    }

    public Integer getOnTheAirAllLastAirDateInt() {
        return onTheAirAllLastAirDateInt;
    }

    public void setOnTheAirAllLastAirDateInt(Integer onTheAirAllLastAirDateInt) {
        this.onTheAirAllLastAirDateInt = onTheAirAllLastAirDateInt;
    }

    public int getOnTheAirAllLatestSeason() {
        return onTheAirAllLatestSeason;
    }

    public void setOnTheAirAllLatestSeason(int onTheAirAllLatestSeason) {
        this.onTheAirAllLatestSeason = onTheAirAllLatestSeason;
    }

    public int getOnTheAirAllLatestEpisode() {
        return onTheAirAllLatestEpisode;
    }

    public void setOnTheAirAllLatestEpisode(int onTheAirAllLatestEpisode) {
        this.onTheAirAllLatestEpisode = onTheAirAllLatestEpisode;
    }
}
